# Copyright (c) [2024] [Daniel Pozsar]
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import pytest
from useful import *


@pytest.mark.parametrize(
    "a, b, c",
    [
        (tau_x, tau_y, tau_z),
        (tau_z, tau_x, tau_y),
        (tau_y, tau_z, tau_x),
        (tau_z, tau_y, -tau_x),
    ],
)
def test_comm(a, b, c):
    assert (comm(a, b) == 2j * c).all()


@pytest.mark.parametrize(
    "dirs, NUMK, out",
    [
        ("", 10, np.array([[0, 0, 0]])),
        (
            "x",
            10,
            np.array(
                [
                    [0.0, 0.0, 0.0],
                    [0.1, 0.0, 0.0],
                    [0.2, 0.0, 0.0],
                    [0.3, 0.0, 0.0],
                    [0.4, 0.0, 0.0],
                    [0.5, 0.0, 0.0],
                    [0.6, 0.0, 0.0],
                    [0.7, 0.0, 0.0],
                    [0.8, 0.0, 0.0],
                    [0.9, 0.0, 0.0],
                ]
            ),
        ),
        (
            "xy",
            3,
            np.array(
                [
                    [0.0, 0.0, 0.0],
                    [0.33333333, 0.0, 0.0],
                    [0.66666667, 0.0, 0.0],
                    [0.0, 0.33333333, 0.0],
                    [0.0, 0.66666667, 0.0],
                    [0.33333333, 0.33333333, 0.0],
                    [0.33333333, 0.66666667, 0.0],
                    [0.66666667, 0.33333333, 0.0],
                    [0.66666667, 0.66666667, 0.0],
                ]
            ),
        ),
    ],
)
def test_make_kset(dirs, NUMK, out):
    assert (make_kset(dirs, NUMK) == out).all()
